==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/common/view_zastup_uzivatele.php <==
<?php
/**
 * stanislav.elbl, 10.11.2017
 */

namespace RonPortal\Common;

use Ron\Http\App;
use Ron\MessageManager;
use Ron\MVC\Model;
use Ron\StringUtils;
use RonPortal\Prava;
use RonPortal\Security;
use RonPortal\User;
use RonPortal\ZastupUzivateleInfo;

/** @var ZastupUzivateleInfo[] $zastupy */
$zastupy = Model::getInstance() ->getData('aktualniZastupy');

?>
<h1><?= \Ron\ronText('Zastup_uzivatele') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<?php foreach ($zastupy as $zastup) { ?>
    <div class="form large-form">
        <div class="form-content">
        <div class="zastupInfo">
            <?= StringUtils::format('date', $zastup ->platnostOd) ?> - <?= $zastup ->platnostDo ? StringUtils::format('date', $zastup ->platnostDo) : \Ron\ronText('platnost_do_neomezeno') ?>
            <?php if (User::hasRC($zastup ->zastupujici)) { ?><?= \Ron\ronText('zastupujete_uzivatele') ?> <?= StringUtils::htmlTextConvert($zastup ->zastupovanyInfo) ?>
            <?php } else if (User::hasRC($zastup ->zastupujici)) { ?><?= \Ron\ronText('vas_zastupuje_uzivatel') ?> <?= StringUtils::htmlTextConvert($zastup ->zastupujiciInfo) ?>
            <?php } else { ?><?= sprintf(\Ron\ronText('uzivatele_zastupuje_uzivatel'), StringUtils::htmlTextConvert($zastup ->zastupovanyInfo), StringUtils::htmlTextConvert($zastup ->zastupujiciInfo)) ?>
            <?php } ?>
        </div>

        <div class="zastupPodrobnosti zastupPoznamka">
            <?= StringUtils::longTextToHtml($zastup ->poznamka) ?>
        </div>

        <div class="zastupRole">
            <h4><?= \Ron\ronText('Vybrane_role') ?></h4>
            <?php foreach ($zastup ->role as $role) { ?>
                <div class="zastupVybranaRole" title="<?= StringUtils::htmlTextConvert($role ->poznamka) ?>"><?= StringUtils::htmlTextConvert($role ->popis) ?></div>
            <?php } ?>
        </div>

        <?php if (User::jeZastup()  ||  User::hasRC($zastup ->zastupujici)) { ?>
            <!-- Jsem zastupujici => potvrzeni zastupu a editace vyjadreni -->
            <form method="POST" action="?menuid=zastupuzivatele&action=zapisvyjadreni">
                <?= Security::csrfHiddenInput() ?>
                <?php if ($zastup ->potvrzeni != 3) { /* u zrusenych tlacitka nezobrazi */ ?>
                    <div class="zastupTlacitka">
                        <?php if ($zastup ->potvrzeni != 1) { ?>
                            <input class="button" type="submit" name="potvrdit" value="<?= \Ron\ronText('Potvrdit_zastup') ?>">
                        <?php } ?>

                        <?php if ($zastup ->potvrzeni != 2) { ?>
                            <input class="button" type="submit" name="zamitnout" value="<?= \Ron\ronText('Zamitnout_zastup') ?>">
                        <?php } ?>
                    </div>
                <?php } ?>

                <div class="zastupPotvrzeni <?= ($zastup ->potvrzeni == 1) ? 'potvrzeno' : (($zastup ->potvrzeni == 2) ? 'zamitnuto' : (($zastup ->potvrzeni == 3) ? 'zruseno' : 'nepotvrzeno'))?>">
                    <?php if ($zastup ->potvrzeni) { ?>
                        <?= \Ron\ronText('Zastup_potvrzeni_' . $zastup ->potvrzeni) ?> (<?= StringUtils::format('datetime', $zastup ->casPotvrzeni) ?>)
                    <?php } else { ?>
                        <?= \Ron\ronText('Zastup_potvrzeni_0') ?>
                    <?php } ?>
                </div>

                <div class="zastupVyjadreni">
                    <div><?= \Ron\ronText('Vyjadreni') ?>:</div>
                    <input type="hidden" name="idZastupu" value="<?= $zastup ->id ?>">
                    <div>
                        <textarea class="form-input" rows="10" name="vyjadreni"><?= StringUtils::htmlTextConvert($zastup ->vyjadreniZastupujiciho) ?></textarea>
                    </div>
                </div>

                <div>
                    <input type="submit" class="submitbutton" value="<?= \Ron\ronText('Ulozit_vyjadreni') ?>" />
                </div>
            </form>
        <?php } else { ?>
            <?php if ($zastup ->potvrzeni != 3) { ?>
                <div class="zastupTlacitka">
                    <button class="button confirmQuestion" id="zrusit"
                            data-ron-confirm-text="<?= \Ron\ronText('Opravdu_zrusit_zastup') ?>"
                            data-ron-href="?menuid=zastupuzivatele&action=zrusitzastup&id=<?= $zastup->id ?><?= Security::csrfUrlParameter() ?>"><?= \Ron\ronText('Zrusit_zastup') ?></button>
                </div>
            <?php } ?>

            <div class="zastupPotvrzeni <?= ($zastup ->potvrzeni == 1) ? 'potvrzeno' : (($zastup ->potvrzeni == 2) ? 'zamitnuto' : (($zastup ->potvrzeni == 3) ? 'zruseno' : 'nepotvrzeno'))?>">
                <?= \Ron\ronText('Zastup_potvrzeni_' . $zastup ->potvrzeni) ?>

                <?php if ($zastup ->potvrzeni) { ?>
                     (<?= StringUtils::format('datetime', $zastup ->casPotvrzeni) ?>)
                <?php } ?>
            </div>
            <?php if ($zastup ->vyjadreniZastupujiciho) { ?>
                <div class="zastupVyjadreni">
                    <div><?= \Ron\ronText('Vyjadreni') ?>:</div>
                    <div class="zastupPodrobnosti zastupTextVyjadreni">
                        <?= StringUtils::longTextToHtml($zastup ->vyjadreniZastupujiciho) ?>
                    </div>
                </div>
            <?php } ?>
        <?php } ?>
        </div>

        <div class="buttons">
            <?php if (Prava::vratPrava('zast_uz_komu') ->lzeZobrazitRC($zastup ->zastupovany)) { ?>
            <div>
                <a href="?menuid=zastupuzivatele&formaction=edit&record=<?= $zastup ->id ?>"><?= \Ron\ronText('Upravit') ?></a>
            </div>
            <?php } ?>

            <h4 class="zastupNadpisAktivita"><?= \Ron\ronText('Zaznam_aktivity_zastupu') ?></h4>
            <div class="zastupAktivita zastupPodrobnosti autoExpand">
                <?= StringUtils::longTextToHtml($zastup ->zaznamAktivity) ?>
            </div>
        </div>
    </div>
<?php } ?>

<?php if (!User::jeZastup()) { ?>
<div>
    <a href="?menuid=zastupuzivatele"><?= \Ron\ronText('Zpet_na_moje_zastupy') ?></a>
</div>
<?php } ?>

<?php if (App::getDebugMode()) {
    echo '<h2>DEBUG> Aktualni prava uzivatele</h2>';
    var_dump($_SESSION['prava']);
} ?>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/common/view_zastup_uzivatele.php <==
<?php
/**
 * stanislav.elbl, 10.11.2017
 */

namespace RonPortal\Common;

use Ron\Http\App;
use Ron\Http\Csrf;
use Ron\MessageManager;
use Ron\MVC\Model;
use Ron\StringUtils;
use RonPortal\Prava;
use RonPortal\User;
use RonPortal\ZastupUzivateleInfo;

/** @var ZastupUzivateleInfo[] $zastupy */
$zastupy = Model::getInstance() ->getData('aktualniZastupy');

?>
<h1><?= \Ron\ronText('Zastup_uzivatele') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<?php foreach ($zastupy as $zastup) { ?>
    <div class="form large-form">
        <div class="form-content">
        <div class="zastupInfo">
            <?= StringUtils::format('date', $zastup ->platnostOd) ?> - <?= $zastup ->platnostDo ? StringUtils::format('date', $zastup ->platnostDo) : \Ron\ronText('platnost_do_neomezeno') ?>
            <?php if (User::hasRC($zastup ->zastupujici)) { ?><?= \Ron\ronText('zastupujete_uzivatele') ?> <?= StringUtils::htmlTextConvert($zastup ->zastupovanyInfo) ?>
            <?php } else if (User::hasRC($zastup ->zastupujici)) { ?><?= \Ron\ronText('vas_zastupuje_uzivatel') ?> <?= StringUtils::htmlTextConvert($zastup ->zastupujiciInfo) ?>
            <?php } else { ?><?= sprintf(\Ron\ronText('uzivatele_zastupuje_uzivatel'), StringUtils::htmlTextConvert($zastup ->zastupovanyInfo), StringUtils::htmlTextConvert($zastup ->zastupujiciInfo)) ?>
            <?php } ?>
        </div>

        <div class="zastupPodrobnosti zastupPoznamka">
            <?= StringUtils::longTextToHtml($zastup ->poznamka) ?>
        </div>

        <div class="zastupRole">
            <h4><?= \Ron\ronText('Vybrane_role') ?></h4>
            <?php foreach ($zastup ->role as $role) { ?>
                <div class="zastupVybranaRole" title="<?= StringUtils::htmlTextConvert($role ->poznamka) ?>"><?= StringUtils::htmlTextConvert($role ->popis) ?></div>
            <?php } ?>
        </div>

        <?php if (User::jeZastup()  ||  User::hasRC($zastup ->zastupujici)) { ?>
            <!-- Jsem zastupujici => potvrzeni zastupu a editace vyjadreni -->
            <form method="POST" action="?menuid=zastupuzivatele&action=zapisvyjadreni">
                <?= Csrf::csrfHiddenInput() ?>
                <?php if ($zastup ->potvrzeni != 3) { /* u zrusenych tlacitka nezobrazi */ ?>
                    <div class="zastupTlacitka">
                        <?php if ($zastup ->potvrzeni != 1) { ?>
                            <input class="button" type="submit" name="potvrdit" value="<?= \Ron\ronText('Potvrdit_zastup') ?>">
                        <?php } ?>

                        <?php if ($zastup ->potvrzeni != 2) { ?>
                            <input class="button" type="submit" name="zamitnout" value="<?= \Ron\ronText('Zamitnout_zastup') ?>">
                        <?php } ?>
                    </div>
                <?php } ?>

                <div class="zastupPotvrzeni <?= ($zastup ->potvrzeni == 1) ? 'potvrzeno' : (($zastup ->potvrzeni == 2) ? 'zamitnuto' : (($zastup ->potvrzeni == 3) ? 'zruseno' : 'nepotvrzeno'))?>">
                    <?php if ($zastup ->potvrzeni) { ?>
                        <?= \Ron\ronText('Zastup_potvrzeni_' . $zastup ->potvrzeni) ?> (<?= StringUtils::format('datetime', $zastup ->casPotvrzeni) ?>)
                    <?php } else { ?>
                        <?= \Ron\ronText('Zastup_potvrzeni_0') ?>
                    <?php } ?>
                </div>

                <div class="zastupVyjadreni">
                    <div><?= \Ron\ronText('Vyjadreni') ?>:</div>
                    <input type="hidden" name="idZastupu" value="<?= $zastup ->id ?>">
                    <div>
                        <textarea class="form-input" rows="10" name="vyjadreni"><?= StringUtils::htmlTextConvert($zastup ->vyjadreniZastupujiciho) ?></textarea>
                    </div>
                </div>

                <div>
                    <input type="submit" class="submitbutton" value="<?= \Ron\ronText('Ulozit_vyjadreni') ?>" />
                </div>
            </form>
        <?php } else { ?>
            <?php if ($zastup ->potvrzeni != 3) { ?>
                <div class="zastupTlacitka">
                    <button class="button confirmQuestion" id="zrusit"
                            data-ron-confirm-text="<?= \Ron\ronText('Opravdu_zrusit_zastup') ?>"
                            data-ron-href="?menuid=zastupuzivatele&action=zrusitzastup&id=<?= $zastup->id ?><?= Csrf::csrfUrlParameter() ?>"><?= \Ron\ronText('Zrusit_zastup') ?></button>
                </div>
            <?php } ?>

            <div class="zastupPotvrzeni <?= ($zastup ->potvrzeni == 1) ? 'potvrzeno' : (($zastup ->potvrzeni == 2) ? 'zamitnuto' : (($zastup ->potvrzeni == 3) ? 'zruseno' : 'nepotvrzeno'))?>">
                <?= \Ron\ronText('Zastup_potvrzeni_' . $zastup ->potvrzeni) ?>

                <?php if ($zastup ->potvrzeni) { ?>
                     (<?= StringUtils::format('datetime', $zastup ->casPotvrzeni) ?>)
                <?php } ?>
            </div>
            <?php if ($zastup ->vyjadreniZastupujiciho) { ?>
                <div class="zastupVyjadreni">
                    <div><?= \Ron\ronText('Vyjadreni') ?>:</div>
                    <div class="zastupPodrobnosti zastupTextVyjadreni">
                        <?= StringUtils::longTextToHtml($zastup ->vyjadreniZastupujiciho) ?>
                    </div>
                </div>
            <?php } ?>
        <?php } ?>
        </div>

        <div class="buttons">
            <?php if (Prava::vratPrava('zast_uz_komu') ->lzeZobrazitRC($zastup ->zastupovany)) { ?>
            <div>
                <a href="?menuid=zastupuzivatele&formaction=edit&record=<?= $zastup ->id ?>"><?= \Ron\ronText('Upravit') ?></a>
            </div>
            <?php } ?>

            <h4 class="zastupNadpisAktivita"><?= \Ron\ronText('Zaznam_aktivity_zastupu') ?></h4>
            <div class="zastupAktivita zastupPodrobnosti autoExpand">
                <?= StringUtils::longTextToHtml($zastup ->zaznamAktivity) ?>
            </div>
        </div>
    </div>
<?php } ?>

<?php if (!User::jeZastup()) { ?>
<div>
    <a href="?menuid=zastupuzivatele"><?= \Ron\ronText('Zpet_na_moje_zastupy') ?></a>
</div>
<?php } ?>

<?php if (App::getDebugMode()) {
    echo '<h2>DEBUG> Aktualni prava uzivatele</h2>';
    var_dump($_SESSION['prava']);
} ?>
